@@ -1,6 +1,7 @@
 __all__ = [
     "Client",
     "CollectionClient",
+    "CollectionSearch",
     "ConformanceClasses",
     "ItemSearch",
     "Modifiable",
@@ -10,6 +11,7 @@ __all__ = [
 from pystac_client._utils import Modifiable
 from pystac_client.client import Client
 from pystac_client.collection_client import CollectionClient
+from pystac_client.collection_search import CollectionSearch
 from pystac_client.conformance import ConformanceClasses
 from pystac_client.item_search import ItemSearch
 from pystac_client.version import __version__
